BarcodeElement class

条形码元素

Inheritance

Constructors

BarcodeElement({required int x, required int y, required String data, int width = 160, int height = 60, bool showText = true})

Properties

data String
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showText bool
final
type LabelElementType
finalinherited
width int
final
x int
finalinherited
y int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited