ImageElement class

图片元素

Inheritance

Constructors

ImageElement({required int x, required int y, required Uint8List image, required int width, required int height})

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
final
image Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type LabelElementType
finalinherited
width int
final
x int
finalinherited
y int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited