QRCodeErrorCorrectionLevel enum

二维码容错率

Inheritance
Available extensions

Values

low → const QRCodeErrorCorrectionLevel

7% 的纠错能力

medium → const QRCodeErrorCorrectionLevel

15% 的纠错能力

quartile → const QRCodeErrorCorrectionLevel

25% 的纠错能力

high → const QRCodeErrorCorrectionLevel

30% 的纠错能力

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QRCodeErrorCorrectionLevel>
A constant List of the values in this enum, in order of their declaration.