TextElement class

文本元素

Inheritance

Constructors

TextElement({required int x, required int y, required String text, int fontSize = 24, bool bold = false, int? width, int? height})

Properties

bold bool
final
fontSize int
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
type LabelElementType
finalinherited
width int?
final
x int
finalinherited
y int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited