QRCodeElement class
二维码元素
- Inheritance
-
- Object
- LabelElement
- QRCodeElement
Constructors
- QRCodeElement({required int x, required int y, required String data, int size = 120, QRCodeErrorCorrectionLevel errorCorrectionLevel = QRCodeErrorCorrectionLevel.medium})
Properties
- data → String
-
final
- errorCorrectionLevel → QRCodeErrorCorrectionLevel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
final
- type → LabelElementType
-
finalinherited
- x → int
-
finalinherited
- y → int
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited